@@ -1,3 +1,6 @@
+# -*- coding: utf-8 -*-
+
+
 class Singleton(object):
     """Singleton Class
     This is a class to make some class being a Singleton class.
@@ -13,8 +16,6 @@ class Singleton(object):
     """
 
     def __new__(cls, *args, **kwargs):
-        if not hasattr(cls, '_instance'):
-            orig = super(Singleton, cls)
-            cls._instance = orig.__new__(cls, *args, **kwargs)
+        if not hasattr(cls, "_instance"):
+            cls._instance = super().__new__(cls, *args, **kwargs)
         return cls._instance
-
